| memory_exp | R Documentation |
Data were obtained from eight replicated experiments. The data were collected on the first day of class as part of the first Dr. MacKinnon's (2018) classroom teaching. The pedagogical value of the experiment was that students would have first-hand knowledge of the experiment thereby increasing their understanding of course concepts. Permission to use the data was obtained from the university Institutional Review Board.
data(memory_exp)
A data frame with 369 rows and 5 variables:
Replication ID, ranges from 1 to 8
Use of repetition rehearsal technique, ranges from 1 to 12
Total words recalled out of 20 words, ranges from 3 to 20
Use of imagery rehearsal technique on a 1 to 9 scale
A factor with two levels: "repetition" (primary rehearsal) or "imagery" (secondary rehearsal)
If you use the data set, please cite the original article by MacKinnon et al. (2018) cited below.
MacKinnon, D. P., Valente, M. J., & Wurpts, I. C. (2018). Benchmark validation of statistical models: Application to mediation analysis of imagery and memory. Psychological Methods, 23, 654–671. \Sexpr[results=rd]{tools:::Rd_expr_doi("https://doi.org/10.1037/met0000174")}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.